@@ -26,7 +26,11 @@ sub load_from_source_data {
  
     my ($self, $source_data) = @_;
     if ($source_data) {
-        foreach my $field (keys %$source_data) {
+		# Hack that allows us to set link_id reliably when creating a MoreCommen
+		# object from Comment. This ensures that link_id is always set before 
+		# replies.
+        #foreach my $field (keys %$source_data) {
+        foreach my $field (sort keys %$source_data) {
             # Set data fields
             my $setter = sprintf 'set_%s', $field;
             if ($self->can($setter)) {
